@@ -36,6 +36,7 @@ class InferredFieldType(Enum):
     number = {"expression": "`text_number-dev-1`(File.text)", "type": "NUMBER"}
     timestamp = {"expression": "`text_date-dev-1`(File.text)", "type": "TIMESTAMP"}
     checkbox = {"expression": "checkbox(File.text)", "type": "STRING"}
+    signature = {"expression": "region_signature(File.text)", "type": "STRING"}
     table = {
         "expression": "entity_one_many(File.text)",
         "type": "ENTITY",
@@ -80,6 +81,7 @@ class IQLError(Exception):
 class ResourceType(str, Enum):
     fc = "fc"
     dc = "dc"
+    ec = "ec"
     collection = "collection"
 
 
@@ -148,6 +150,21 @@ class Impira:
 
         return resp.json()["uids"]
 
+    @validate_arguments
+    def add_files_to_collection(self, collection_id: str, file_ids: List[str]):
+        resp = requests.post(
+            self._build_resource_url("ec", "file_collection_contents"),
+            headers=self.headers,
+            json={
+                "data": [
+                    {"file_uid": u, "collection_uid": collection_id} for u in file_ids
+                ]
+            },
+        )
+
+        if not resp.ok:
+            raise APIError(resp)
+
     @validate_arguments
     def get_app_url(self, resource_type: ResourceType, resource_id: str) -> str:
         return self._build_resource_url(
