@@ -59,6 +59,12 @@ class ScalarLabel(BaseModel):
 class NumberLabel(ScalarLabel):
     value: Optional[Union[StrictInt, StrictFloat, float]]
 
+    def fmt(self):
+        if self.value is None:
+            return None
+        else:
+            return str(self.value)
+
 
 class TextLabel(ScalarLabel):
     value: Optional[str]
@@ -83,6 +89,8 @@ class TimestampLabel(ScalarLabel):
 class CheckboxLabel(ScalarLabel):
     value: Optional[bool]
 
+class SignatureLabel(ScalarLabel):
+    value: Optional[bool]
 
 def traverse(record: Any, fn: Callable[[Any], None]):
     if isinstance(record, ScalarLabel):
